zotonic_notifier (zotonic_notifier v1.0.0-rc.17)
Extension system using notifications with fold, map and priorities.
Summary
Functions
Unsubscribe an owner from an event
Unsubscribe an owner from an event
Detach all observers owned by the pid
Detach all observers owned by the pid
Return the result of the first observer returning something else than 'undefined'. Return 'undefined' if none.
Return the result of the first observer returning something else than 'undefined'. Return 'undefined' if none.
Return the list of all observers for a specific event
Call all observers, return a list of all return values.
Notify the first observer. Pids async, M:F sync.
Notify the first observer. Pids async, M:F sync.
Notify observers async. Start separate process for the notification.
Notify observers async. Start separate process for the notification.
Notify observers. Pids async, M:F sync.
Notify observers. Pids async, M:F sync.
Register an observer pid.
Register an observer with an owner pid.
Register an observer with the default notifier. Higher prio (lower nr) gets called earlier.
Register an observer. Higher prio (lower nr) gets called earlier.
Types
Functions
Unsubscribe an owner from an event
Unsubscribe an owner from an event
-spec detach_all(pid()) -> ok.
Detach all observers owned by the pid
Detach all observers owned by the pid
Return the result of the first observer returning something else than 'undefined'. Return 'undefined' if none.
Return the result of the first observer returning something else than 'undefined'. Return 'undefined' if none.
Return the list of all observers for a specific event
Call all observers, return a list of all return values.
Notify the first observer. Pids async, M:F sync.
Notify the first observer. Pids async, M:F sync.
Notify observers async. Start separate process for the notification.
Notify observers async. Start separate process for the notification.
Notify observers. Pids async, M:F sync.
Notify observers. Pids async, M:F sync.
Register an observer pid.
Register an observer with an owner pid.
Register an observer with the default notifier. Higher prio (lower nr) gets called earlier.
Register an observer. Higher prio (lower nr) gets called earlier.